@@ -16,9 +16,11 @@ my @op_bookmark_fields = (
     "DISPLAY URL",
     "ICONFILE",
     "ID",
+    "IN PANEL",
     "MOVE_IS_COPY",
     "NAME",
     "ON PERSONALBAR",
+    "PANEL_POS",
     "PARTNERID",
     "PERSONALBAR_POS",
     "SEPARATOR_ALLOWED",
